<?php
/**
 * PizzaHouse Framework: messages subsystem
 *
 * @package	pizzahouse
 * @since	pizzahouse 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('pizzahouse_messages_theme_setup')) {
	add_action( 'pizzahouse_action_before_init_theme', 'pizzahouse_messages_theme_setup' );
	function pizzahouse_messages_theme_setup() {
		// Core messages strings
		add_filter('pizzahouse_filter_localize_script', 'pizzahouse_messages_localize_script');
	}
}


/* Session messages
------------------------------------------------------------------------------------- */

if (!function_exists('pizzahouse_get_error_msg')) {
	function pizzahouse_get_error_msg() {
		return pizzahouse_storage_get('error_msg');
	}
}

if (!function_exists('pizzahouse_set_error_msg')) {
	function pizzahouse_set_error_msg($msg) {
		$msg2 = pizzahouse_get_error_msg();
		pizzahouse_storage_set('error_msg', trim($msg2) . ($msg2=='' ? '' : '<br />') . trim($msg));
	}
}

if (!function_exists('pizzahouse_get_success_msg')) {
	function pizzahouse_get_success_msg() {
		return pizzahouse_storage_get('success_msg');
	}
}

if (!function_exists('pizzahouse_set_success_msg')) {
	function pizzahouse_set_success_msg($msg) {
		$msg2 = pizzahouse_get_success_msg();
		pizzahouse_storage_set('success_msg', trim($msg2) . ($msg2=='' ? '' : '<br />') . trim($msg));
	}
}

if (!function_exists('pizzahouse_get_notice_msg')) {
	function pizzahouse_get_notice_msg() {
		return pizzahouse_storage_get('notice_msg');
	}
}

if (!function_exists('pizzahouse_set_notice_msg')) {
	function pizzahouse_set_notice_msg($msg) {
		$msg2 = pizzahouse_get_notice_msg();
		pizzahouse_storage_set('notice_msg', trim($msg2) . ($msg2=='' ? '' : '<br />') . trim($msg));
	}
}


/* System messages (save when page reload)
------------------------------------------------------------------------------------- */
if (!function_exists('pizzahouse_set_system_message')) {
	function pizzahouse_set_system_message($msg, $status='info', $hdr='') {
		update_option(pizzahouse_storage_get('options_prefix') . '_message', array('message' => $msg, 'status' => $status, 'header' => $hdr));
	}
}

if (!function_exists('pizzahouse_get_system_message')) {
	function pizzahouse_get_system_message($del=false) {
		$msg = get_option(pizzahouse_storage_get('options_prefix') . '_message', false);
		if (!$msg)
			$msg = array('message' => '', 'status' => '', 'header' => '');
		else if ($del)
			pizzahouse_del_system_message();
		return $msg;
	}
}

if (!function_exists('pizzahouse_del_system_message')) {
	function pizzahouse_del_system_message() {
		delete_option(pizzahouse_storage_get('options_prefix') . '_message');
	}
}


/* Messages strings
------------------------------------------------------------------------------------- */

if (!function_exists('pizzahouse_messages_localize_script')) {
	
	function pizzahouse_messages_localize_script($vars) {
		$vars['strings'] = array(
			'ajax_error'		=> esc_html__('Invalid server answer', 'pizzahouse'),
			'bookmark_add'		=> esc_html__('Add the bookmark', 'pizzahouse'),
            'bookmark_added'	=> esc_html__('Current page has been successfully added to the bookmarks. You can see it in the right panel on the tab \'Bookmarks\'', 'pizzahouse'),
            'bookmark_del'		=> esc_html__('Delete this bookmark', 'pizzahouse'),
            'bookmark_title'	=> esc_html__('Enter bookmark title', 'pizzahouse'),
            'bookmark_exists'	=> esc_html__('Current page already exists in the bookmarks list', 'pizzahouse'),
			'search_error'		=> esc_html__('Error occurs in AJAX search! Please, type your query and press search icon for the traditional search way.', 'pizzahouse'),
			'email_confirm'		=> esc_html__('On the e-mail address "%s" we sent a confirmation email. Please, open it and click on the link.', 'pizzahouse'),
			'reviews_vote'		=> esc_html__('Thanks for your vote! New average rating is:', 'pizzahouse'),
			'reviews_error'		=> esc_html__('Error saving your vote! Please, try again later.', 'pizzahouse'),
			'error_like'		=> esc_html__('Error saving your like! Please, try again later.', 'pizzahouse'),
			'error_global'		=> esc_html__('Global error text', 'pizzahouse'),
			'name_empty'		=> esc_html__('The name can\'t be empty', 'pizzahouse'),
			'name_long'			=> esc_html__('Too long name', 'pizzahouse'),
			'email_empty'		=> esc_html__('Too short (or empty) email address', 'pizzahouse'),
			'email_long'		=> esc_html__('Too long email address', 'pizzahouse'),
			'email_not_valid'	=> esc_html__('Invalid email address', 'pizzahouse'),
			'subject_empty'		=> esc_html__('The subject can\'t be empty', 'pizzahouse'),
			'subject_long'		=> esc_html__('Too long subject', 'pizzahouse'),
			'text_empty'		=> esc_html__('The message text can\'t be empty', 'pizzahouse'),
			'text_long'			=> esc_html__('Too long message text', 'pizzahouse'),
			'send_complete'		=> esc_html__("Send message complete!", 'pizzahouse'),
			'send_error'		=> esc_html__('Transmit failed!', 'pizzahouse'),
			'not_agree'			=> esc_html__('Please, check \'I agree with Terms and Conditions\'', 'pizzahouse'),
			'login_empty'		=> esc_html__('The Login field can\'t be empty', 'pizzahouse'),
			'login_long'		=> esc_html__('Too long login field', 'pizzahouse'),
			'login_success'		=> esc_html__('Login success! The page will be reloaded in 3 sec.', 'pizzahouse'),
			'login_failed'		=> esc_html__('Login failed!', 'pizzahouse'),
			'password_empty'	=> esc_html__('The password can\'t be empty and shorter then 4 characters', 'pizzahouse'),
			'password_long'		=> esc_html__('Too long password', 'pizzahouse'),
			'password_not_equal'	=> esc_html__('The passwords in both fields are not equal', 'pizzahouse'),
			'registration_success'	=> esc_html__('Registration success! Please log in!', 'pizzahouse'),
			'registration_failed'	=> esc_html__('Registration failed!', 'pizzahouse'),
			'geocode_error'			=> esc_html__('Geocode was not successful for the following reason:', 'pizzahouse'),
			'googlemap_not_avail'	=> esc_html__('Google map API not available!', 'pizzahouse'),
			'editor_save_success'	=> esc_html__("Post content saved!", 'pizzahouse'),
			'editor_save_error'		=> esc_html__("Error saving post data!", 'pizzahouse'),
			'editor_delete_post'	=> esc_html__("You really want to delete the current post?", 'pizzahouse'),
			'editor_delete_post_header'	=> esc_html__("Delete post", 'pizzahouse'),
			'editor_delete_success'	=> esc_html__("Post deleted!", 'pizzahouse'),
			'editor_delete_error'	=> esc_html__("Error deleting post!", 'pizzahouse'),
			'editor_caption_cancel'	=> esc_html__('Cancel', 'pizzahouse'),
			'editor_caption_close'	=> esc_html__('Close', 'pizzahouse')
			);
		return $vars;
	}
}
?>